#!/usr/bin/env

import time
import json
import sys
import os

from sonic_platform import platform

HOST_CHK_CMD = "docker > /dev/null 2>&1"


def is_host():
    return os.system(HOST_CHK_CMD) == 0


print "============================ NEW API REPORT ============================="

platform = platform.Platform()
chassis = platform.get_chassis()

print "\n=============================== TEST CHASSIS API ===============================\n"

print "Base Mac:\t\t", chassis.get_base_mac()
print "Serial No.:\t\t", chassis.get_serial_number()
print "System EEPROM:\t\t", json.dumps(
    chassis.get_system_eeprom_info(), indent=1)
print "Reboot Cause:\t\t", chassis.get_reboot_cause()

if not is_host():

    print "\n=============================== TEST FAN API ===============================\n"

    num_fan = chassis.get_num_fans()
    all_fan = chassis.get_all_fans()
    print "num of fans:\t", num_fan

    for fan in all_fan:
        print ""
        print "Name:\t\t\t", fan.get_name()
        print "Present:\t\t", fan.get_presence()
        print "Status:\t\t\t", fan.get_status()
        print "Model:\t\t\t", fan.get_model()
        print "Serial:\t\t\t", fan.get_serial()

        if fan.get_status():

            print "Direction:\t\t", fan.get_direction()
            print "Target Speed:\t\t", fan.get_target_speed()
            print "Speed Tolerance:\t", fan.get_speed_tolerance()

            print "LED Color:\t\t", fan.get_status_led()
            print "Set color red 1 sec:\t", fan.set_status_led("red")
            time.sleep(1)
            print "LED Color:\t\t", fan.get_status_led()
            print "Set color green:\t", fan.set_status_led("green")

            print "Speed:\t\t\t", fan.get_speed()
            print "Set speed 100 7 sec:\t", fan.set_speed(100)
            time.sleep(7)
            print "Speed:\t\t\t", fan.get_speed()
            print "Set speed 40:\t\t", fan.set_speed(40)
            time.sleep(7)

    print "\n=============================== TEST PSU API ===============================\n"

    num_psu = chassis.get_num_psus()
    all_psu = chassis.get_all_psus()
    print "num of psus: ", num_psu
    for psu in all_psu:
        print ""
        print "Name:\t\t\t", psu.get_name()
        print "Present:\t\t", psu.get_presence()
        print "Status:\t\t\t", psu.get_status()
        print "Model:\t\t\t", psu.get_model()
        print "Serial:\t\t\t", psu.get_serial()

        print "Voltage:\t\t", psu.get_voltage()
        print "Current:\t\t", psu.get_current()
        print "Power:\t\t\t", psu.get_power()

        print "Power status:\t\t", psu.get_powergood_status()
        print "Set LED off:\t\t", psu.set_status_led("off")
        print "LED Status:\t\t", psu.get_status_led()
        print "Set LED green:\t\t", psu.set_status_led("green")
        print "LED Status:\t\t", psu.get_status_led()

        print "\nPSU fans"
        psu_fans = psu.get_all_fans()
        for fan in psu_fans:
            print "\n\tName:\t\t\t", fan.get_name()
            print "\tPresent:\t\t", fan.get_presence()
            print "\tDirection:\t\t", fan.get_direction()
            print "\tSpeed:\t\t\t", fan.get_speed()

    print "\n=============================== TEST THERMAL API ===============================\n"

    all_thermal = chassis.get_all_thermals()
    for thermal in all_thermal:
        print ""
        print "Name:\t\t\t", thermal.get_name()
        print "Present:\t\t", thermal.get_presence()
        print "Status:\t\t\t", thermal.get_status()
        print "Model:\t\t\t", thermal.get_model()
        print "Serial:\t\t\t", thermal.get_serial()

        print "Temp:\t\t\t", thermal.get_temperature()

        print "High threshold:\t\t", thermal.get_high_threshold()
        print "Set high threshold 97:\t", thermal.set_high_threshold(97)
        time.sleep(1)
        print "New High threshold:\t", thermal.get_high_threshold()

        print "Low threshold:\t\t", thermal.get_low_threshold()
        print "Set low threshold 30:\t", thermal.set_low_threshold(30)
        time.sleep(1)
        print "New low threshold:\t", thermal.get_low_threshold()

    print "\n=============================== TEST WATCHDOG API ===============================\n"

    wdt = chassis.get_watchdog()

    print "WDT obj:\t\t", wdt
    print "Is arm:\t\t\t", wdt.is_armed()
    print "Remaining time:\t\t", wdt.get_remaining_time()
    print "ARM 60 sec:\t\t", wdt.arm(60)
    print "Wait 5 sec..."
    time.sleep(5)
    print "Remaining time:\t\t", wdt.get_remaining_time()
    print "Disarm:\t\t\t", wdt.disarm()
    print "Is arm:\t\t\t", wdt.is_armed()
    print "Remaining time:\t\t", wdt.get_remaining_time()

    print "\n=============================== TEST SFP API ===============================\n"

    num_sfp = chassis.get_num_sfps()
    all_sfp = chassis.get_all_sfps()
    print "num of sfps: ", num_sfp
    for idx in range(1, num_sfp+1):
        sfp = chassis.get_sfp(idx)

        print ""
        print "Name:\t\t\t\t", sfp.get_name()
        print "Model:\t\t\t\t", sfp.get_model()
        print "Status:\t\t\t\t", sfp.get_status()
        print "Present:\t\t\t", sfp.get_presence()
        print "Serial NO:\t\t\t", sfp.get_serial()

        if sfp.get_status():

            print "Info:\t\t\t", json.dumps(
                sfp.get_transceiver_info(), indent=1)
            print "Bulk status:\t\t", json.dumps(
                sfp.get_transceiver_bulk_status(), indent=1)
            print "Threshold info:\t\t", json.dumps(
                sfp.get_transceiver_threshold_info(), indent=1)

            print "RX los:\t\t\t\t", sfp.get_rx_los()
            print "TX fault:\t\t\t", sfp.get_tx_fault()
            print "Temperature:\t\t\t", sfp.get_temperature()
            print "voltage:\t\t\t", sfp.get_voltage()
            print "Tx_bias:\t\t\t", sfp.get_tx_bias()
            print "RX_power:\t\t\t", sfp.get_rx_power()
            print "Tx_power:\t\t\t", sfp.get_tx_power()

            # RESET
            print "Reset status:\t\t\t", sfp.get_reset_status()
            print "Reset:\t\t\t\t", sfp.reset()
            time.sleep(3)
            print "Reset status:\t\t\t", sfp.get_reset_status()

            # POWER OVERRIDE
            print "Power override status:\t\t", sfp.get_power_override()
            print "Set Power override true:\t", sfp.set_power_override(
                True, True)
            time.sleep(3)
            print "Power override status:\t\t", sfp.get_power_override()
            print "Power override false:\t\t", sfp.set_power_override(
                False, False)

            # TX DISABLE
            print "Tx disable status:\t\t", sfp.get_tx_disable()
            print "Set tx disable true:\t\t", sfp.tx_disable(True)
            time.sleep(3)
            print "Tx disable status:\t\t", sfp.get_tx_disable()
            print "Set tx disable false:\t\t", sfp.tx_disable(False)

            # TX DISABLE CHANNEL
            print "Tx disable channel :\t\t", sfp.get_tx_disable_channel()
            print "Set tx disable 0 true:\t\t", sfp.tx_disable_channel(0, True)
            time.sleep(3)
            print "Tx disable channel :\t\t", sfp.get_tx_disable_channel()
            print "Set tx disable 0 false:\t\t", sfp.tx_disable_channel(
                0, False)

            # LP MODE
            print "LPmode status:\t\t\t", sfp.get_lpmode()
            print "Set LP mode true:\t\t", sfp.set_lpmode(True)
            time.sleep(3)
            print "LPmode status:\t\t\t", sfp.get_lpmode()
            print "Set LP mode false:\t\t", sfp.set_lpmode(False)

else:

    print "\n=============================== TEST COMPONENT API ===============================\n"

    num_com = chassis.get_num_components()
    all_comm = chassis.get_all_components()

    img_path_dict = {
        'SW_CPLD1': '/home/admin/img/fishbone48_swcpld1_v04_20190531.vme',
        'SW_CPLD2': '/home/admin/img/fishbone48_swcpld2_v04_20190531.vme',
        'BASE_CPLD': '/home/admin/img/fishbone_BASE_NoRefresh_V06_20190308.vme',
        'CPU_CPLD': '/home/admin/img/fishbone_COME_V07_NoRefresh_20190308.vme',
        'FAN_CPLD': '/home/admin/img/fishbone_FAN-cpld_V0.1_20190113.vme',
        'FPGA': '/home/admin/img/fpga.bin',
    }

    print "num of chassis:\t", num_com
    for com in all_comm:
        print ""
        print "Name:\t\t\t", com.get_name()
        print "Description:\t\t", com.get_description()
        print "Firmware Version:\t", com.get_firmware_version()
        img_path = img_path_dict.get(com.get_name(), "None")
        # print "Install CPLD {}:\t\t".format(img_path), com.install_firmware(img_path)
